<?php
/**
 * Plugin Name: GPT - Calendar Redirect Link
 * Description: Creates a custom endpoint `/onboard-gpt-coder` that redirects visitors to a specified URL set in the admin settings page.
 * Author: WPGPTCoder
 * Author URI: https://www.wpappdev.com/product/wp-gpt-coder/
 * Version: 1.0
 * Slug: calendar-redirect-link-11867568
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class GPT_Calendar_Redirect_Link_11867568 {
    private $redirect_option_name = 'gpt_calendar_redirect_url_11867568';

    public function __construct() {
        add_action('init', array($this, 'add_custom_endpoint'));
        add_action('template_redirect', array($this, 'redirect_to_custom_link'));
        add_action('admin_menu', array($this, 'add_plugin_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
    }

    public function add_custom_endpoint() {
        add_rewrite_rule('^onboard-gpt-coder/?', 'index.php?onboard_gpt_coder=1', 'top');
        add_rewrite_tag('%onboard_gpt_coder%', '([^&]+)');
    }

    public function redirect_to_custom_link() {
        $is_endpoint = intval(get_query_var('onboard_gpt_coder', 0));
        if ($is_endpoint) {
            $redirect_url = get_option($this->redirect_option_name);
            if (!empty($redirect_url)) {
                wp_redirect($redirect_url);
                exit;
            }
        }
    }

    public function add_plugin_admin_menu() {
        add_options_page(
            'Calendar Redirect Link Settings',
            'Calendar Redirect Link',
            'manage_options',
            'calendar-redirect-link-settings-11867568',
            array($this, 'create_admin_page')
        );
    }

    public function create_admin_page() {
        ?>
        <div class="wrap">
            <h2>Calendar Redirect Link Settings</h2>
            <form method="post" action="options.php">
                <?php
                settings_fields('calendar_redirect_link_group_11867568');
                do_settings_sections('calendar-redirect-link-settings-11867568');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    public function register_settings() {
        register_setting(
            'calendar_redirect_link_group_11867568',
            $this->redirect_option_name,
            array('sanitize_callback' => 'esc_url_raw')
        );

        add_settings_section(
            'calendar_redirect_link_section_11867568',
            'Redirect Settings',
            null,
            'calendar-redirect-link-settings-11867568'
        );

        add_settings_field(
            'calendar_redirect_link_field_11867568',
            'Redirect URL',
            array($this, 'redirect_url_field_callback'),
            'calendar-redirect-link-settings-11867568',
            'calendar_redirect_link_section_11867568'
        );
    }

    public function redirect_url_field_callback() {
        $url = get_option($this->redirect_option_name);
        echo '<input type="url" id="' . $this->redirect_option_name . '" name="' . $this->redirect_option_name . '" value="' . esc_attr($url) . '" class="regular-text" />';
    }
}

function gpt_calendar_redirect_link_activate_11867568() {
    flush_rewrite_rules();
}

function gpt_calendar_redirect_link_deactivate_11867568() {
    flush_rewrite_rules();
}

register_activation_hook(__FILE__, 'gpt_calendar_redirect_link_activate_11867568');
register_deactivation_hook(__FILE__, 'gpt_calendar_redirect_link_deactivate_11867568');

new GPT_Calendar_Redirect_Link_11867568();